@@ -66,3 +66,16 @@ class RADUSERGROUP(Base):
 
     def __repr__(self):
         return repr(self)
+
+
+class RADREPLY(Base):
+    __tablename__ = 'radreply'
+
+    id = Column(Integer, primary_key=True)
+    username = Column(String(length=128), unique=True, nullable=False, default='')
+    attribute = Column(String(length=128), nullable=False, default='')
+    op = Column(String(length=2), nullable=False, default='==')
+    value = Column(String(length=128), nullable=False, default='')
+
+    def __repr__(self):
+        return repr(self)
