@@ -2,7 +2,7 @@ import enum
 
 from fibrenest_db_models.common import *
 from sqlalchemy.dialects.postgresql import INET, MACADDR, CIDR
-from sqlalchemy import Text, text, BigInteger, Index
+from sqlalchemy import Text, text, BigInteger, Index, SmallInteger, LargeBinary
 
 
 class ONTSwapType(enum.Enum):
@@ -58,12 +58,41 @@ class ONT(Base):
         return repr(self)
 
 
-class PUBLICPOOL(Base):
-    __tablename__ = 'public_pool'
+class PUBLICIPPOOL(Base):
+    __tablename__ = 'public_ip_pool'
 
     id = Column(Integer, primary_key=True)
     bng_ip = Column(INET, nullable=False)
     pool = Column(CIDR, nullable=False)
+    kea_subnet_id = Column(Integer, nullable=False)
+
+
+class HostIdentifierType(Base):
+    __tablename__ = 'host_identifier_type'
+
+    type = Column(SmallInteger, primary_key=True)
+    name = Column(String(32), server_default=text("NULL::character varying"))
+
+
+class Host(Base):
+    __tablename__ = 'hosts'
+
+    host_id = Column(Integer, primary_key=True, server_default=text("nextval('hosts_host_id_seq'::regclass)"))
+    dhcp_identifier = Column(LargeBinary, nullable=False)
+    dhcp_identifier_type = Column(ForeignKey('host_identifier_type.type', ondelete='CASCADE'), nullable=False, index=True)
+    dhcp4_subnet_id = Column(BigInteger)
+    dhcp6_subnet_id = Column(BigInteger)
+    ipv4_address = Column(BigInteger)
+    hostname = Column(String(255), server_default=text("NULL::character varying"))
+    dhcp4_client_classes = Column(String(255), server_default=text("NULL::character varying"))
+    dhcp6_client_classes = Column(String(255), server_default=text("NULL::character varying"))
+    dhcp4_next_server = Column(BigInteger)
+    dhcp4_server_hostname = Column(String(64), server_default=text("NULL::character varying"))
+    dhcp4_boot_file_name = Column(String(128), server_default=text("NULL::character varying"))
+    user_context = Column(Text)
+    auth_key = Column(String(32), server_default=text("NULL::character varying"))
+
+    host_identifier_type = relationship('HostIdentifierType')
 
 
 class RADACCT(Base):
